@@ -1,7 +1,7 @@
 from restresource import RESTResource
 from tasty.model import *
-from json import write as jsonify
-from tasty.helpers import sqlobject_to_strings, xmlify, htmlify, deunicodify
+from simplejson import dumps as jsonify
+from tasty.helpers import sqlobject_to_strings, xmlify, htmlify, deunicodify, broadcast_event
 from types import *
 
 class Dimension(RESTResource):
@@ -30,6 +30,8 @@ class Dimension(RESTResource):
     def delete(self,obj):
         delete_rels(self.main.s,self.main.obj["user"],self.main.obj["item"],self.main.obj["tag"],
                      self.main.obj["-user"],self.main.obj["-item"],self.main.obj["-tag"])
+        hub.commit()
+        broadcast_event("deleted",dict(service=self.main.s.name,args=self.main.to_event_str()))        
         return "ok"
     delete.expose_resource = True
 
@@ -49,6 +51,8 @@ class Dimension(RESTResource):
         if len(self.parents) == 1:
             return "ok"
         build_all_relationships(self.main.obj["user"],self.main.obj["item"],self.main.obj["tag"])
+        hub.commit()
+        broadcast_event("updated",dict(service=self.main.s.name,args=self.main.to_event_str()))                
         return "ok"
     update.expose_resource = True
 
@@ -82,4 +86,5 @@ class Dimension(RESTResource):
         else:
             o = self.rclass(**dict([(self.rclass_id_name,id),("service",service)]))
             self.main.obj[self.rclassname].append(o)
+        hub.commit()
         return o
