@@ -1,6 +1,6 @@
 from sqlobject import *
 from turbogears.database import PackageHub
-from mx import DateTime
+from datetime import datetime as DateTime
 
 hub = PackageHub("tasty")
 __connection__ = hub
