@@ -18,10 +18,10 @@ build_controllers()
 
 if __name__ == "__main__":
 
-    if exists(join(dirname(__file__), "setup.py")):
+    if len(sys.argv) < 2:
         cherrypy.config.update(file=join(dirname(__file__),"dev.cfg"))
     else:
-        cherrypy.config.update(file=join(dirname(__file__),"prod.cfg"))
+        cherrypy.config.update(file=join(dirname(__file__),"%s.cfg" % sys.argv[1]))
     
     cherrypy.server.start()
 
